% Matlab script instrusion_1D_thermal_response.m
% Todd Ehlers, University of Michigan  Oct, 2004
%
% This program calculates the thermal repsonse to a 1D intrusion.
% Equation taken from Stuwe 2002, #3.89, pg. 104.
%
%

% CLEAR VARIABLES
close all
clear all

% ***
% *** USER DEFINED VARIABLES BELOW
% ***

Tb = 50;           % Background, country rock temperature [C]
Ti = 700;           % Intrustion temperature at time =0 [C]
l = [0.1, 1.0, 5.0];            % width of the intrusion [km]
k = 32;             % thermal diffusivity of rock [km^2/Ma]
z = [0:0.01:10];      % distance from center of intrusion solution will be calculated over [km]
t= [20e-6 1000e-6 10000e-6 100000e-6 1000000e-6 10000000e-6];    % times at which solution will be calculated [Ma]

% *** END USER DEFINED VARIALBES

% ***
% *** CALCULATE SOLUTION
% ***

for j=1:length(t)   % loop over all time steps
for i=1:length(z)   % loop over each distance from center of intrusion
    T1(i,j) = Tb + ((Ti-Tb)/2)*(erf((0.5*l(1)-z(i))/(sqrt(4*k*t(j)))) + (erf((0.5*l(1)+z(i))/(sqrt(4*k*t(j))))) );
    T2(i,j) = Tb + ((Ti-Tb)/2)*(erf((0.5*l(2)-z(i))/(sqrt(4*k*t(j)))) + (erf((0.5*l(2)+z(i))/(sqrt(4*k*t(j))))) );
    T3(i,j) = Tb + ((Ti-Tb)/2)*(erf((0.5*l(3)-z(i))/(sqrt(4*k*t(j)))) + (erf((0.5*l(3)+z(i))/(sqrt(4*k*t(j))))) );
end % end for i
end % end for j

% ***
% *** PLOT SOLUTION
% ***
    figure
    orient tall

    % PLOT 100 M WIDE INTRUSION TEMPERATURE HISTORY
    subplot(311)
    plot(z,T1(:,1),'k-')
    hold on
    plot(z,T1(:,2),'k--')
    plot(z,T1(:,3),'k-.')
    plot(z,T1(:,4),'k-')
    plot(z,T1(:,5),'k:')
    
    xlabel('Distance from Center of Intrusion (km)')
    ylabel('Temperature (C)')
    title('Intrusion Width = 100 m')
    legend('20 years','1000','10,000','100,000','1 Myr');
    axis([0,0.2,50,750])

    % PLOT 1 KM WIDE INTRUSION TEMPERATURE HISTORY
    subplot(312)
    plot(z,T2(:,1),'k-')
    hold on
    plot(z,T2(:,2),'k--')
    plot(z,T2(:,3),'k-.')
    plot(z,T2(:,4),'k-')
    plot(z,T2(:,5),'k:')
    xlabel('Distance from Center of Intrusion (km)')
    ylabel('Temperature (C)')
    title('Intrusion Width = 1 km')
    legend('20 years','1000','10,000','100,000','1 Myr');
    axis([0,2,50,750])

    % PLOT 5 KM WIDE INTRUSION TEMPERATURE HISTORY
    subplot(313)
    plot(z,T3(:,1),'k-')
    hold on
    plot(z,T3(:,2),'k--')
    plot(z,T3(:,3),'k-.')
    plot(z,T3(:,4),'k-')
    plot(z,T3(:,5),'k:')
    plot(z,T3(:,6),'k-.')
    xlabel('Distance from Center of Intrusion (km)')
    ylabel('Temperature (C)')
    title('Intrusion Width = 5 km')
    legend('20 years','1000','10,000','100,000','1 Myr', '10 Myr');
    axis([0,10,50,750])




% ***
% *** END OF PROGRAM
% ***